package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````3"8``#0````@T0```````#0`(``+
M`"@`&P`:``8````T````-````#0```!@`0``8`$```0````$`````P```)0!
M``"4`0``E`$``!,````3````!`````$````!````````````````````L!$`
M`+`1```$`````!````$`````(````"`````@```(4```"%````4`````$```
M`0````"`````@````(```'1-``!T30``!``````0```!````P,T``,#=``#`
MW0``4`(``)02```&`````!````(```#(S0``R-T``,C=```(`0``"`$```8`
M```$````!````*@!``"H`0``J`$``$0```!$````!`````0```!0Y71D/+\`
M`#R_```\OP``]````/0````$````!````%'E=&0`````````````````````
M``````8````0````4N5T9,#-``#`W0``P-T``$`"``!``@``!`````$````O
M;&EB+VQD+6QI;G5X+G-O+C(```0````0`````0```$=.50```````P````(`
M````````!````!0````#````1TY5`#-\4E6F<*"EX4L/;I#`P3^G=<SL$0``
M`$L````(````"``````0$`0E0`2`*`$``:"&`("``0``"R@$"#B@$D6*```(
M`````$L```!.````40```%(```!8````60```%H```!<````70````````!?
M````80```&(```!C``````````````!NQ=\?SMY'+6M_FGPNQ9NVU&34?"'_
MY`[9<5@<XD?&`;(!BV^L2^/`PN4_++KCDGS[H6Q@:PE#UF>OS&9"1=7LB0=P
MTPT4XIXR8MOMV\WCG@PZEPM9Z.WL?ZF<F^&G`@JCX/M)````````````````
M``````0"`````````````!(```!E`@`````````````2````4`(`````````
M````$@````P!`````````````!(```"3```````````````2`````0$`````
M````````$0```*,"`````````````!(```"3`0`````````````2````C@(`
M````````````$@```"(!`````````````!(````1```````````````@````
M5@(`````````````$@```,0"`````````````!(```#R`@`````````````2
M````4@,`````````````$@```/P!`````````````!(```!3`0``````````
M```2````M```````````````$@```$,!`````````````!(````U`0``````
M```````2````-@,`````````````$@```.4"`````````````!(```#;`0``
M```````````2````%0(`````````````$@```"```````````````"````"Q
M`0`````````````2````$0$`````````````$@```+$"`````````````!(`
M```H`P`````````````2````/```````````````(````+P"````````````
M`!(```!6```````````````2````@P$`````````````$@```',`````````
M`````!(```#P```````````````2````A```````````````$@```/D"````
M`````````!(```#.`@`````````````1````G`(`````````````$@```'H"
M`````````````!(```!)`@`````````````2`````@0`````````````$@``
M`-0``````````````!(```#5`@`````````````2````2@,`````````````
M$0```'4!`````````````!(```!``@`````````````2````]@$`````````
M````$@```&<!`````````````!(```"!`@`````````````2````J@$`````
M````````$@```!8!`````````````!(```!D`P`````````````2````B`(`
M````````````$@```$D#`````````````"$```!S`@`````````````2````
MW`(`````````````$@```"`#`````````````!(```"?```````````````2
M````G@$`````````````$@```!(#`````````````!(```!(`P``````````
M```1````7@(`````````````$@```#@"`````````````!(```#O`0``````
M```````2````XP``````````````$0```+P!`````````````!$```!<`0``
M```````````2````9```````````````$@```&P"`````````````!(````O
M`P`````````````2`````P,`````````````(@```#,"`````````````!(`
M``#"```````````````2````"P0``,!N``!V````$@`.`$T$``#@7@``5PP`
M`!(`#@!#`P```"0``$P"```2``X`=0,``%!8```%````$@`.`*H#``!`:P``
M?@,``!(`#@!S!```8%@```4"```2``X`/`0``!#@````````$``8`(8#``!P
M6@``*0```!(`#@#``P``4%T``'8````2``X`)`(```2````$````$0`0`"0$
M``#P5@``.P```!(`#@!(!```5/`````````0`!@`800``!!>``#&````$@`.
M`!<$````X````````!``%P#D`P``H%H``-@````2``X`6@0``!#@````````
M$``7`(`$```,X```!````!$`%P"3`P``H&\```$````2``X`'00``$PF````
M````$@`.`"P$``!`;P``50```!(`#@`9!````.`````````@`!<`HP,```"`
M```$````$0`0`/`#``#070``-P```!(`#@#.`P``D%<``+8````2``X`B@0`
M`(!;``#0`0``$@`.``!L:6)P97)L+G-O+C4N,C@`7U]G;6]N7W-T87)T7U\`
M7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L
M;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T
M9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O
M86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`
M4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`
M4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?
M=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N
M`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?
M1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L
M7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!P=&AR96%D
M7V=E='-P96-I9FEC`&]P96XV-`!C;&]S90!L<V5E:S8T`%]?97)R;F]?;&]C
M871I;VX`<F5A9`!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`97AI=`!S=')N
M8VUP`&-L;W-E9&ER`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R:6YT
M9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER
M`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H
M:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C
M:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?
M96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL`'!A
M<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!?
M9G!?:'<`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?9&%T85]S=&%R=`!X<U]I;FET
M`%]?;&EB8U]C<W5?:6YI=`!?7V)S<U]S=&%R=`!?96YD`'!A<E]M:W1M<&1I
M<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A
M<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?,BXQ+C,`1TQ)0D-?,BXT`$=,24)#
M7S(N,RXR`$=,24)#7S(N,@!'3$E"0U\R+C,N-`!'3$E"0U\R+C```````@`#
M``,`````````!`````0```````,`!0`#``8`!P````````````,`!``"``(`
M``````,`!0`#`````P``````````````!0`#``,``P`#``,````#``,````#
M``(````#``,````(``,``P`#``,``P``````!``#``,``P`'````````````
M`P`#``D``P````$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$````!``8`&@(``!````!P````<Q]I"0``"0"7!```
M$````!1I:0T```@`HP0``!````!R&6D)```&`*T$```0````$FEI#0``!0"Y
M!```$````'09:0D```0`PP0``!`````0:6D-```#`,\$`````````0`"`,L!
M```0`````````!)I:0T```<`N00``!`````0:6D-```"`,\$````````P-T`
M``@```#$W0``"````/S?```(````!.````@````,X```"````,S?```&!@``
MT-\```8*``#4WP``!@L``-C?```&&0``W-\```8>``#@WP``!B$``.3?```&
M(@``Z-\```8F``#LWP``!BT``/#?```&0@``]-\```9#``#XWP``!D@``-S>
M```'`0``X-X```<"``#DW@``!P,``.C>```'!```[-X```<%``#PW@``!P<`
M`/3>```'"```^-X```<)``#\W@``!PP```#?```'#0``!-\```<.```(WP``
M!P\```S?```'$```$-\```<1```4WP``!Q(``!C?```'$P``'-\```<4```@
MWP``!Q4``"3?```'%@``*-\```<7```LWP``!Q@``##?```'&@``--\```<;
M```XWP``!QP``#S?```''0``0-\```<?``!$WP``!R```$C?```'(P``3-\`
M``<D``!0WP``!R4``%3?```')P``6-\```<H``!<WP``!RD``&#?```'*@``
M9-\```<K``!HWP``!RP``&S?```'+@``<-\```<O``!TWP``!S```'C?```'
M,0``?-\```<R``"`WP``!S,``(3?```'-```B-\```<U``",WP``!S8``)#?
M```'.```E-\```<Y``"8WP``!SH``)S?```'.P``H-\```<\``"DWP``!ST`
M`*C?```'/P``K-\```=```"PWP``!T$``+3?```'1```N-\```=%``"\WP``
M!T8``,#?```'1P``Q-\```=)``#(WP``!TH`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z(<&``"!P\>^``"+@P0!``"%P'0"_]"#Q`A;P_^S!````/^C"```
M``````#_HPP```!H`````.G@_____Z,0````:`@```#IT/____^C%````&@0
M````Z<#_____HQ@```!H&````.FP_____Z,<````:"````#IH/____^C(```
M`&@H````Z9#_____HR0```!H,````.F`_____Z,H````:#@```#I</____^C
M+````&A`````Z6#_____HS````!H2````.E0_____Z,T````:%````#I0/__
M__^C.````&A8````Z3#_____HSP```!H8````.D@_____Z-`````:&@```#I
M$/____^C1````&AP````Z0#_____HT@```!H>````.GP_O___Z-,````:(``
M``#IX/[___^C4````&B(````Z=#^____HU0```!HD````.G`_O___Z-8````
M:)@```#IL/[___^C7````&B@````Z:#^____HV````!HJ````.F0_O___Z-D
M````:+````#I@/[___^C:````&BX````Z7#^____HVP```!HP````.E@_O__
M_Z-P````:,@```#I4/[___^C=````&C0````Z4#^____HW@```!HV````.DP
M_O___Z-\````:.````#I(/[___^C@````&CH````Z1#^____HX0```!H\```
M`.D`_O___Z.(````:/@```#I\/W___^CC````&@``0``Z>#]____HY````!H
M"`$``.G0_?___Z.4````:!`!``#IP/W___^CF````&@8`0``Z;#]____HYP`
M``!H(`$``.F@_?___Z.@````:"@!``#ID/W___^CI````&@P`0``Z8#]____
MHZ@```!H.`$``.EP_?___Z.L````:$`!``#I8/W___^CL````&A(`0``Z5#]
M____H[0```!H4`$``.E`_?___Z.X````:%@!``#I,/W___^CO````&A@`0``
MZ2#]____H\````!H:`$``.D0_?___Z/$````:'`!``#I`/W___^CR````&AX
M`0``Z?#\____H\P```!H@`$``.G@_/___Z/0````:(@!``#IT/S___^CU```
M`&B0`0``Z<#\____H]@```!HF`$``.FP_/___Z/<````:*`!``#IH/S___^C
MX````&BH`0``Z9#\____H^0```!HL`$``.F`_/___Z/H````:+@!``#I</S_
M__^C[````&C``0``Z6#\____H_````!HR`$``.E0_/___Z/T````:-`!``#I
M0/S___^C^````&C8`0``Z3#\____HR@!``!FD```````````C4PD!(/D\/]Q
M_%6)Y5>)SU93Z'D"``"!P[FZ``!1@^PLBT$$B474BT$(B4709:$4````B47D
M,<"-1=!0C4744%'H6O___XN#``$``(/$#%!0_[,4`0``Z%1+``"+@R`!``"#
MQ!"`.``/A#(!``"+L_P```"#[`S_-NCB_/__@(BV`@```EK_-NC3_/__@\00
M@(BV`@```8L'@\`%/?___S\/AX(!``"#[`S!X`)0Z(W^__^+==2+#X/$$(F#
M=!$``(L6B4W,QX-X$0``!````(D0C9,(H___B5`$BY,\`0``B5`(C9,+H___
MB5`,@_D!?AV+?<R-5@2-2!"--+YFD(LZ@\($@\$$B7G\.=9U\8M]S(/L#,=$
MN`P`````@\<#:@!0C8-@>/__5U#_LX`1``#H6OO__X/$((G&A<`/A)8```"#
M[`S_LX`1``"-?>#H3/W__XGZC8/8H?__Z-\J``"#Q!"%P`^$A0```(/L#/^S
M@!$``.CF^O__Z%'\__^#Q!")\(M-Y&4S#10````/A;,```"-9?!96UY?78UA
M_,/HV_O__XF#@!$``(7`#X2*````@^P,4.@T_/__B[/\````6?\VZ);[__^#
MQ!#&@&$&````Z9O^__^#[`S_LX`1``#H&?O__X/$$(G&Z5+___^+@WP1``"%
MP'01@^P,4.B\2```@\00Z6#___^)^HV#C:'__^@G*@``B8-\$0``A<`/A$7_
M___KTE!0C8.*H?___[,D`0``4.CS_/__@^P,:@'HB?W__^B420``,>U>B>&#
MY/!05%+H(@```('#=+@``(V#T)#__U"-@W"0__]045;_LRP!``#HP_K___2+
M'"3#9I!FD&:09I!FD&:09I"+'"3#9I!FD&:09I!FD&:0Z.````"!PBNX``"-
MBD`!``"-@D`!```YR'0=BX((`0``A<!T$U6)Y8/L%%'_T(/$$,G#C70F`)##
MC;0F`````.B@````@<+KMP``58GE4XV*0`$``(V"0`$``(/L!"G(P?@"B</!
MZQ\!V-'X=!2+D@P!``"%TG0*@^P(4%'_TH/$$(M=_,G#C;0F`````&:058GE
M4^A7____@<.7MP``@^P$@+M0`0```'4GBX,H`0``A<!T$8/L#/^S-`$``.B-
M_/__@\00Z#7____&@U`!```!BUW\R<.-M"8`````9I#I6____XL4),-FD&:0
M9I"058U0.%=64X'L#`,``(E$)&B-1"1XC:PD@````&6+'10```")G"3\`@``
M,=N)1"0(C9PD``$``(E$)!")="08B7PD'(G?C78`BTH$BP+'1?P`````@\40
MQT7T`````(/""`_(B47HB<C!Z`B)#"0E`/\``,=$)`0`````B<.)R,'H&`G8
MBQPDB=G!XPC!X1@)R(G9@>$``/\`"<&)3?`Y[W6FBU0D"(M$)!"!P@`"``")
MQ8D4)(UV`(M5:(M%;(/%",=%?``````S53@S13PS50@S10PS5?@S1?R)QXG1
MB=`!T0^L^!\)P8E->#LL)'7(BVPD:(MU%(M%`(M-"(M]'(M5!(M=#(ET)`2+
M=1B)3"08B<&)?"0,BWT@#ZS1&XET)`B)QHE<)!S!Y@6+71"+;20)SHE\)%")
M5"04BWPD4#'2`WPD>(EL)%2)^8ML)%03;"1\B1PD@<&9>8):B40D$(GKB?"#
MTP`!R(M,)!@1VHL<)(E$)"")5"0DBU0D"(G=,=6)[R'/B?J+?"0(BT0D(,=$
M)"0`````BVPD'(M,)`S'1"0\`````#'ZBWPD&,=$)$0``````=")^HG^B40D
M((L$),'B'@^L[@*)TXM4)`@)\P.4)(`````3C"2$````B5PD.(MT)#B)7"0P
MB<N)T8M4)!2!P9EY@EJ#TP`QQHM$)!")3"0HB?>+="0@BTPD*(E<)"PAQ\=$
M)"P`````B?N+/"2)\#'[BWPD)`'9P>`%B40D*(G]B?>+="0H#ZSO&PG^B?"+
M="0$`<B)1"0HBT0D$(G!#ZS0`L'A'HG+"<.)W8E<)$"+'"0#G"2(````BTPD
M,,=$)$P`````$[0DC````(G8BWPD)`69>8):B?*+="0@@](`,>DQVR'.,W0D
M.(GQ`<&+1"0H$=.+5"0LB4PD,(G&B5PD-(M<)#P/K-`;P>8%QT0D-`````")
MP0GQBW0D((G(`T0D,(GR#ZS^`HE$)#"+?"0PP>(>B?&)U@G.BTPD.`.,))``
M``")R!.<))0```")="1(!9EY@EJ)VH/2`#'U(VPD*#-L)$")Z3';BVPD-`'!
MB?@1T\'@!8E,)"`/K.\;B5PD)(G#"?N)V`-$)"")1"0@QT0D)`````"+3"0H
MBUPD+,=$)#P`````B<C!X!X/K-D"BUPD1,=$)$0`````B<()RHM,)$`#C"28
M````B<@3G"2<````B=6)5"0X!9EY@EJ)VHGQBW0D2(/2`#'I(TPD,(E$)"B)
M5"0LBT0D((G*,=LQ\HG1`TPD*!-<)"S!X`6)3"0HBU0D)(G!BT0D((E<)"R+
M7"0TQT0D+``````/K-`;B40D0`M,)$")R(M,)#`#1"0HB40D*(G(#ZS9`L'@
M'HG""<J)5"1``[0DH````(GPBW0D.(E4)%@%F7F"6C'5(VPD((M4)"PQ[HM<
M)"3'1"0T`````(GQQT0D3``````!P8M$)"B)QHG'P>8%#ZS7&XET)#"+="0P
M"?Z)\`'(BTPD((E$)#")SL'F'HGPB<X/K-X"BUPD/(GQB<8)SHM,)#@#C"2H
M````B<@3G"2L````BTPD6(GU!9EY@EJ)VHET)$B#T@`Q\8MT)"@QVR'.,W0D
M0(GQ`<&+1"0P$=.+5"0TB4PD((G&B5PD)(M,)"@/K-`;P>8%QT0D)`````")
MPPGSB=@#1"0@BUPD+(E$)"")R,'@'@^LV0*)Q@G.B70D.(M,)$`#C"2P````
MBU0D)(ET)%B)R(M<)#3'1"0L``````69>8):,?6+="1((VPD,,=$)#P`````
M,?7'1"1$`````(GI`<&+1"0@P>`%B40D*(M$)""+;"0H#ZS0&XE$)$`+;"1`
MB>@!R(M,)#")1"0HB<@/K-D"P>`>B<()R@.T)+@```"+3"18B?"+="0XB=6)
M5"1`!9EY@EHQT2-,)""+5"0L,<Z)\0'!BT0D*(G&P>8%B70D,(G&#ZS6&XET
M)$B+="0P"W0D2(GP`<B)1"0PQT0D-`````"+7"0@BW0D)(M\)##'1"0D````
M`(G:B=F+7"0LQT0D3``````/K/$"P>(>QT0D/``````)RHM,)#@#C"3`````
MB<B)5"1(!9EY@EHQU2-L)"@S;"1`B>F+;"0TB50D6`'!B?C!X`4/K.\;B40D
M((MT)"`)_HGPBW0D2`'(BTPD*(E$)"")R`^LV0+!X!Z)P@G*BTPD0`.,),@`
M``")R(M,)%B)U8E4)#@%F7F"6C'1(TPD,(M4)"0QSHGQ`<&+1"0@P>`%B<:+
M1"0@#ZS0&XE$)"@+="0HB?`!R(E$)"C'1"0L`````(M,)#"+7"0TBW0D.,=$
M)#0`````B<C'1"1$`````,'@'@^LV0*+7"0\QT0D3`````")P@G*BTPD2`.,
M)-````")R(E4)$`%F7F"6C'5(VPD((E4)%@Q[HM4)"R+;"0DB?$!P8M$)"B)
MSXG!P>$%B4PD,(G1BW0D,(G"#ZS*&PG6B?`!^(M\)"")1"0PB?F)_L'A'@^L
M[@*)R(GQB<8)SHM,)#@#C"38````B<@3G"3<````BTPD6(GU!9EY@EJ)VHET
M)$B#T@`Q\8MT)"@QVR'.,W0D0(GQ`<&+1"0P$=.+5"0TB4PD((G&B5PD)`^L
MT!O!Y@6)PPGSB=@#1"0@BTPD*,=$)"0`````BUPD+(M4)"2)1"0@B<C'1"0\
M`````,'@'@^LV0*+7"0TQT0D+`````")QL=$)$0`````"<Z+3"1``XPDX```
M`(G(B70D.`69>8):B70D6#'UBW0D2"-L)#`Q]8GI`<&+1"0@P>`%B40D*(M$
M)""+;"0H#ZS0&XE$)$`+;"1`B>@!R(M,)#")1"0HB<@/K-D"P>`>B<()R@.T
M).@```"+3"18B?"+="0XB50D0(G5!9EY@EHQT2-,)"`QSHGQ`<&+1"0HBU0D
M+,=$)#0`````BUPD(,=$)$P`````B<;'1"0\`````,'F!8ET)#")Q@^LUAN)
MVHET)$B+="0P"W0D2(GPBW0D),=$)"0``````<B)V<'B'HM<)"P/K/$"B40D
M,(M\)#`)RHM,)#@#C"3P````B<B)5"18!9EY@EHQU2-L)"@S;"1`B>F+;"0T
MB50D2`'!B?C!X`4/K.\;B40D((MT)"`)_HGP`<B+3"0HB40D((G(#ZS9`L'@
M'HG""<J+3"1``XPD^````(G(BTPD6(E4)#B)U069>8):,=$C3"0PBW0D2,=$
M)"P`````BU0D)(M<)#3'1"1$`````#'.QT0D-`````")\<=$)$P``````<&+
M1"0@P>`%B<:+1"0@#ZS0&XE$)"@+="0HB?"+="0X`<B+3"0PB40D*(G(#ZS9
M`HM<)#S!X!Z)P@G*BTPD2`.,)``!``")R(E4)$`%F7F"6C'5(VPD((E4)%@Q
M[HM4)"R+;"0DB?$!P8M$)"B)SXG!P>$%B4PD,(G1BW0D,(G"#ZS*&PG6B?`!
M^(M\)"")1"0PB?F)_L'A'@^L[@*)R(GQB<8)SHM,)#B)="1(`XPD"`$``(GU
M$YPD#`$``(G(BTPD6`69>8):B=J#T@`Q\8MT)"@QVR'.,W0D0(GQ`<&+1"0P
M$=.+5"0TB4PD((G&B5PD)`^LT!O!Y@6+5"0LQT0D)`````")P0GQB<B+3"0@
M`<&+1"0H,?^)SHE,)%B)P0^LT`*+5"1`P>$>B<L)PP.4)!`!``")T(M4)#2)
M7"1`!9EY@EHQW2-L)#`S;"1(B>D!P8GPP>`%B40D((GPBVPD(`^L^!N)1"0H
MBT0D,`ML)"@!Z8E,)&")3"0@B<$/K-`"BU0D2,'A'HG-BTPD3`G%B6PD.`.4
M)!@!``")T!.,)!P!``"+;"1`!:'KV6Z)RHM<)#B#T@")1"0HBT0D((E4)"R+
M5"18,>LQVC';B=$#3"0HBU0D)(E,)"B)P1-<)"S!X06)7"0LB4PD,(G1B<(/
MK,H;BTPD,,=$)"P`````B50D0`M,)$")\HG(BTPD*`'!#ZS^`L'B'HGPB4PD
M*(G6BY0D(`$``(E,)$B+C"0D`0``"<:!PJ'KV6Z)="1`@]$`B=`QVXG*`>B+
M;"1@BTPD+!':BUPD.#'_,?,QW8G+B>X!QA'7BU0D*(ET)#")?"0TB=>)T<'G
M!0^LV1N)_0G-BTPD,`'IB4PD6(MT)""+?"0DBUPD2(E,)#")\<=$)#0`````
MBY0D,`$``,'A'@^L_@*+?"0LQT0D)`````")S8M,)#@)]8NT)"@!``");"0X
M@<:AZ]ENB?`!R(M,)$`QZ3'+BTPD,(G>BUPD-`'&B<C!X`4/K-D;B40D((ML
M)""+1"1`"<T![HET)"")="1(BW0D*(GQ#ZS^`HM\)%C!X1Z)RXN,)#0!```)
M\X'"H>O9;HMT)#B#T0")W8G+B=$QT@'($=HQ[C';,?>)^0'!BT0D(!'3BU0D
M)(E,)"B)QHE<)"R+3"0H#ZS0&\'F!<=$)"P`````B<.+1"0P"?,!V8E,)$")
M3"0HBU0D-(G!P>$>BW0D2,=$)#0`````#ZS0`HM4)"P)P8M$)#B)SXN,)#@!
M``")?"18@<&AZ]EN`<B)^3'I,<Z)\0'!BT0D*,'@!8E$)#"+1"0HBW0D,`^L
MT!N+5"0DQT0D)`````")1"0XBT0D(`MT)#@!\8E,)#")3"1(B<$/K-`"BU0D
M-,'A'HG.BXPD0`$```G&B>B)_8'!H>O9;HET)#@!R#'UBW0D0#'NB?$!P8M$
M)#")SHG!P>$%B4PD((G1B<*+7"0@#ZS*&XM$)"B)\8E4)$`+7"1``=F+5"0L
MB<:)3"1`B4PD((G!#ZS6`L'A'HG+"?.+M"1(`0``B[PD3`$``(M$)%B)W8'&
MH>O9;H/7`#'2`?"+="0X$?J+?"1(,=LQ[C'WB?D!P8M$)"`1TXM4)"2)3"0H
MB<:)7"0L#ZS0&\'F!8M4)#3'1"0L`````(G!QT0D-``````)\8MT)$")R(M,
M)"@!P8M$)#")3"0HB4PD2(G!#ZS0`HN4)%`!``#!X1Z)RPG#BT0D.('"H>O9
M;HG?`=`QZXM4)"R)?"18,=Z)\0'!BT0D*,'@!8E$)#"+1"0HBW0D,`^LT!N+
M5"0DB40D.(M$)"`+="0X`?&)3"1`B4PD,(G!#ZS0`HN4)%@!``#!X1Z)S@G&
M@<*AZ]ENB>B)_0'0B70D.#'UBW0D2(M4)#2+O"1D`0``QT0D)``````Q[HGQ
M`<&+1"0PB<Z)P<'A!8E,)"")T8G"#ZS*&XM,)"")5"1("TPD2(G(B?&+5"0L
M`<&+1"0HB4PD2(E,)"")P8G&BT0D6,'A'@^LU@*)S0GUB[0D8`$``('&H>O9
M;H/7`#'2`?"+="0X$?J+?"1`,=LQ[C'WB?D!P8M$)"`1TXM4)"2)3"0HB<:)
M7"0L#ZS0&\'F!8M4)#3'1"0L`````(G!"?&+="1(B<B+3"0H`<&+1"0PB4PD
M*(E,)$")P0^LT`*+E"1H`0``P>$>B<L)PXM$)#B!PJ'KV6Z)WP'0,>LQWHGQ
M`<&+1"0HP>`%B40D,(M$)"B+5"0LBW0D,,=$)#0`````B7PD6`^LT!N+5"0D
MQT0D)`````")1"0XBT0D(`MT)#@!\8E,)$B)3"0PB<$/K-`"BY0D<`$``,'A
M'HG."<:!PJ'KV6Z)Z(G]`=")="0X,?6+="1`BU0D-(N\)'P!```Q[HGQ`<&+
M1"0PB<Z)P<'A!8E,)"")T8G"#ZS*&XM,)"")5"1`"TPD0(G(B?&+5"0L`<&+
M1"0HB4PD0(E,)"")P8G&BT0D6,'A'@^LU@*)S0GUB[0D>`$``('&H>O9;H/7
M`#'2`?"+="0X$?J+?"1(,=LQ[C'WB?D!P1'3B4PD*(E<)"R+1"0@BU0D),=$
M)"P`````B<8/K-`;P>8%BU0D-,=$)#0`````B<$)\8MT)$")R(M,)"@!P8M$
M)#")3"1(B4PD*(G!#ZS0`HN4)(`!``#!X1Z)RPG#BT0D.('"H>O9;HG?`=`Q
MZXM4)"R)?"18,=Z)\0'!BT0D*,'@!8E$)#"+1"0HBW0D,`^LT!N+5"0DB40D
M.(M$)"`+="0X`?&)3"0PB4PD0(G!#ZS0`HN4)(@!``#!X1Z)S@G&@<*AZ]EN
MB>B)_0'0B70D.#'UBW0D2(M4)#0Q[HGQ`<&+1"0PB<Z)P<'A!8E,)"")T8G"
M#ZS*&XM,)"")5"1("TPD2(G(B?&+5"0LB[PDE`$```'!BT0D*,=$)"0`````
MB4PD2(E,)"")P8G&BT0D6,'A'@^LU@*)S0GUB[0DD`$``('&H>O9;H/7`#'2
M`?"+="0X$?J+?"1`,=LQ[C'WB?D!P8M$)"`1TXM4)"2)3"0HB<:)7"0L#ZS0
M&\'F!8M4)#3'1"0L`````(G!"?&+="1(B<B+3"0H`<&+1"0PB4PD*(E,)%B)
MP0^LT`*+E"28`0``P>$>B<L)PXM$)#B!PJ'KV6Z)WP'0,>N+5"0L,=Z)\0'!
MBT0D*,'@!8E$)#"+1"0HBW0D,`^LT!N)1"0X"W0D.`'QB4PD2(E,)#"+1"0@
MBU0D),=$)#0`````B<&)?"1L#ZS0`L'A'HN4)*`!``#'1"0\`````(G."<:!
MPJ'KV6Z)Z(G]`=")="1`,?6+="18BU0D-(M\)"@Q[HML)"R)\0'!BT0D,(G.
MB<'!X06)3"0@B=&)P@^LRAN+3"0@B50D.`M,)#B)^HG(B?&)_@'!P>(>#ZSN
M`HG5BY0DJ`$``(E,)#B)3"1@BXPDK`$```GU@<*AZ]ENB6PD6(/1`(G0,=N)
MRHM,)&P!R(M,)$`1VHM<)$@Q_S'I,<N)V8G[`<$1TXM4)#B)3"0@BTPD/(E<
M)"2)U\=$)"0`````P><%B<N)T0^LV1N)_@G.B?`#1"0@B40D((MT)#"+?"0T
MQT0D3`````")\<=$)#0`````P>$>#ZS^`HG+BXPDL`$```GSB=V!P:'KV6Z)
M7"1(BYPDM`$``(G(BTPD0(/3`(G:,=L!R(M,)%@1VHM<)&`Q_S'I,<N)V8G[
MBWPD/,=$)#P``````<&)3"0HBTPD(!'3B5PD+(M<)"2)R(G*QT0D+`````#!
MX`4/K-H;B<8)UHM4)"R)\(MT)#@#1"0HB40D*(GQ#ZS^`L'A'HGPB<Z+C"2X
M`0``"<:+1"18@<'<O!N/B?>)="0X`<B)="18"?6+="1((VPD("'^"?6)Z0'!
MBT0D*(G&B<?!Y@4/K-<;B70D,(MT)#`)_HGP`<B)1"0PBTPD((M<)"2+?"1,
MQT0D1`````")R,=$)$P`````P>`>#ZS9`C';B<*+1"0H"<J+3"18B=6)5"1`
M"=&+5"0X(<@AZHG&"=:)\8MT)$@#M"3``0``B?`3O"3$`0``B?H%W+P;CX/2
M``'!BT0D,!'3BU0D-(E,)"")QHE<)"2+7"0L#ZS0&\'F!8G!"?&)R(M,)"@#
M1"0@,?^)QHG(#ZS9`L'@'HG"BT0D.`G*B=$)U8E4)$@C;"0PB50D6(M4)$`A
MR@G5`X0DR`$``(GI!=R\&X\!P8GPP>`%B40D((GPBVPD(`^L^!N)1"0H"VPD
M*(GH`<B)1"0@BTPD,(M<)#2+5"1(QT0D)`````")R,=$)#P`````P>`>#ZS9
M`C';B<4)S8M,)%@AZHEL)#@)Z8G((?`)T(M4)$3'1"1$`````(G!BT0D0`.$
M)-`!```3E"34`0``!=R\&X^#T@`!P8M$)"`1TXE,)"B+5"0DB<&)7"0LP>$%
MQT0D+`````")3"0PB=&)P@^LRAN+3"0PB50D0`M,)$")R(GQ`T0D*,'A'HE$
M)"B)R(GQBW0D2`^L^0*)P@G*B=$)U8E4)$`C;"0@B50D6(M4)#@AR@G5`[0D
MV`$``(M\)"C'1"0T`````(GPB>F+;"0LBUPD)`7<O!N/BU0D0,=$)$P`````
M`<&)^`^L[QO'1"0D`````,'@!<=$)#P`````B40D,(MT)#`)_HGPBW0D.`'(
MBTPD((E$)#")R`^LV0*+7"0LP>`>B<6+1"0H"<V+3"18(>J);"1(">DAR`G0
M`[0DX`$``(M4)#2)P8GP!=R\&X\!P8M$)#")Q@^LT!N)1"0@P>8%"W0D((GP
MBW0D0`'(BTPD*(E$)"")R`^LV0+!X!Z)P@G*B=$)U8E4)#@C;"0PB50D6(M4
M)$@AR@G5`[0DZ`$``(GPB>D%W+P;CP'!BT0D((M4)"3'1"0L`````(ML)#3'
M1"0T`````(G&B<?!Y@4/K-<;BU0D.(ET)"B+="0H"?Z+?"0PB?`!R(GY,=O!
MX1Z)1"0HB<B)^8M\)$P/K.D"B<6+1"0@"<V+3"18(>J);"0P">DAR(G&"=:)
M\8MT)$@#M"3P`0``B?`3O"3T`0``B?H%W+P;CX/2``'!BT0D*!'3BU0D+(E,
M)$")QHE<)$2+7"0D#ZS0&\'F!<=$)$0`````B<$)\8G(BTPD(`-$)$`Q_XG&
MB<@/K-D"P>`>B<*+1"0X"<J)T0G5B50D0"-L)"B)5"1(BU0D,"'*"=4#A"3X
M`0``BUPD+,=$)"0`````B>D%W+P;CXM4)$#'1"0\``````'!B?#!X`6)1"0@
MB?"+;"0@#ZSX&XE$)#@+;"0XB>@!R(M,)"B)1"0@B<@/K-D",=O!X!Z)Q0G-
MBTPD2"'JB6PD.`GIB<@A\`G0BU0D-(G!BT0D,`.$)``"```3E"0$`@``!=R\
M&X^#T@`!P8M$)"`1TXE,)"B+5"0DB<&)7"0LP>$%QT0D+`````")3"0PB=&)
MP@^LRAN+3"0PB50D2`M,)$B)R(GQ`T0D*,'A'HE$)"B)R(GQ#ZSY`HG""<J)
MT0G5B50D2,=$)$P`````(VPD((MT)$"+?"0HB50D6(M4)#B+7"0DQT0D-```
M``#'1"1$`````"'*QT0D)``````)U0.T)`@"``"+5"1(QT0D/`````")\(GI
MBVPD+`7<O!N/`<&)^`^L[QO!X`6)1"0PBW0D,`G^B?"+="0X`<B+3"0@B40D
M,(G(#ZS9`HM<)"S!X!Z)Q8M$)"@)S8M,)%@AZHEL)$`)Z2'("=`#M"00`@``
MBU0D-(G!B?`%W+P;CP'!BT0D,(G&#ZS0&XE$)"#!Y@4+="0@B?`!R(M,)"B)
M1"0@B<@/K-D"P>`>B<()RHG1"=6)5"0XB50D6(M4)$`C;"0PBW0D2,=$)"P`
M````(<H)U0.T)!@"``"+5"0DB?")Z8ML)#3'1"0T``````7<O!N/`<&+1"0@
MB<:)Q\'F!0^LUQN+5"0XB70D*(MT)"@)_HM\)#")\`'(B?DQV\'A'HE$)"B)
MR(GYBWPD1`^LZ0*)Q8M$)"`)S8M,)%@AZHEL)#`)Z2'(B<8)UHGQBW0D0`.T
M)"`"``")\!.\)"0"``")^@7<O!N/@](``<&+1"0H$=.+5"0LB4PD0(G&B5PD
M1(M<)"0/K-`;P>8%B<$)\8G(BTPD(`-$)$`Q_XG&B<@/K-D"P>`>B<()RHG1
M"=6)5"1`QT0D1``````C;"0HBT0D.(M<)"R)5"1(BU0D,,=$)"0`````QT0D
M/``````AR@G5`X0D*`(``(M4)$")Z07<O!N/`<&)\,'@!8E$)"")\(ML)"`/
MK/@;B40D.`ML)#B)Z`'(BTPD*(E$)"")R`^LV0(QV\'@'HG%"<V+3"1((>J)
M;"0X">F)R"'P"="+5"0TB<&+1"0P`X0D,`(``!.4)#0"```%W+P;CX/2``'!
MBT0D(!'3B4PD*(M4)"2)P8E<)"S!X06)3"0PB=&)P@^LRAN+3"0PB50D2`M,
M)$B)R(GQ`T0D*(M4)#C!X1Z)1"0HBUPD)(G(B?''1"0L``````^L^0*)QHM\
M)"C'1"0T``````G.QT0D1``````A\@GU(VPD((ET)#")T(GJB70D2(MT)$`)
MP@.T)#@"``"+;"0LB?")T07<O!N/`<&)^`^L[QO!X`6)1"1`BW0D0`G^B?`!
MR(M,)"`Q_XG&B<@/K-D",=O!X!Z)PHM$)"@)RHM,)$B)U8E4)$`)T8M4)#`A
MR"'J"="+5"0\B<&+1"0X`X0D0`(``!.4)$0"```%W+P;CX/2``'!B?`1T\'@
M!8E,)"")P8GPB5PD)`^L^!N)1"0X"TPD.(G(`T0D((M,)"C'1"0D`````(E$
M)""+7"0LB<C'1"0L`````,'@'@^LV0(QV\=$)#P`````B<*+1"0P"<J)T8E4
M)"@)U8E4)&"+5"1`(?4AR@G5`X0D2`(``(M4)#2)Z1.4)$P"```%W+P;CX/2
M``'!BT0D(!'3B4PD,(M4)"2)P8E<)#3!X07'1"0T`````(E,)#B)T8G"BUPD
M.`^LRAN+3"0PBT0D((E4)$@+7"1(`=F+5"0H,=N)3"18B4PD,(GQ#ZS^`L'A
M'HG-BTPD8`GU">DAZHEL)#@AR(G&"=:)\8MT)$"+?"1$`[0D4`(``!.\)%0"
M``")\(GZ!=R\&X^#T@`!P8M$)#`1TXM4)#2)3"1`B<:)7"1$BWPD1`^LT!O!
MY@4QTHG#BT0D(`GSBW0D0(G!`=X1UXM4)"3!X1Z)="1@B<N)?"1DBTPD*#'_
M#ZS0`@G#`XPD6`(``(E<)$B)R(M<)"P3G"1<`@``!=;!8LJ)VHE$)"")\(/2
M`#-L)$B)5"0DBU0D6#'JB=$#3"0@P>`%B40D((GPBVPD(`^L^!N)1"0H"VPD
M*`'IB4PD6(E,)"#'1"0D`````(M$)#"+5"0TBUPD/(G!P>$>#ZS0`HG-BTPD
M.`G%`XPD8`(``!.<)&0"``")R(G:B6PD0(ML)$@%UL%BRHM,)$"#T@")1"0H
MBT0D(#';B50D+(M4)&`QZ3'*B=$#3"0HBU0D)(E,)"B)P1-<)"S!X06)7"0L
MB4PD,(G1B<(/K,H;P>D;QT0D+`````")5"0XB?*)3"0\BTPD,`M,)#B)R(M,
M)"@!P0^L_@+!XAZ)\(E,)$B)UHN4)&@"``")3"0HBXPD;`(```G&@<+6P6+*
MB70D.(/1`(G0,=N)R@'HBTPD0!':BUPD6#'_,?$QRXM,)"R)W@'&B<L1UXM4
M)"B)="0PB7PD-(G7B=''1"0T`````(M4)"S!YP4/K-D;BUPD2(G^BWPD),=$
M)"0`````"<Z)\(MT)#`!QHET)%B)="0PBW0D((GQ#ZS^`L'A'@GQB<Z+C"1P
M`@``@<'6P6+*B<B+3"1`B70D0`'(BTPD.#'Q,<N+3"0PB=Z+7"0T`<:)R,'@
M!0^LV1N+7"1`B40D((M$)"B+;"0@"<V)P0'NP>$>#ZS0`HG-BY0D>`(``(ET
M)"`)Q8M$)#B!PM;!8LJ);"0X`=`QZXML)%@QW8GI`<&+1"0@P>`%B40D*(M$
M)""+5"0DBVPD*,=$)"P`````#ZS0&XM4)#3'1"0T`````(E$)$B+1"0P"VPD
M2`'IB4PD2(E,)"B)P0^LT`*+5"0LP>$>"<&+1"1`B<V+C"2``@``B6PD0('!
MUL%BR@'(BTPD.#'IB<TQ]8GI`<&+1"0HB<:)QXM$)"#!Y@4/K-<;BU0D)(ET
M)#"+="0P"?Z+?"0T`?&)QHE,)#`/K-8"B4PD6(G!B?#!X1Z)SHN,)(@"```)
MQHM$)#B)]8MT)$"!P=;!8LH!R(EL)#@Q[HML)$@Q]8MT)#")Z8G]`<&)\(GW
MP>`%#ZSO&XE$)""+="0@"?X!\8E,)""+1"0HB<Z+5"0LBVPD6,=$)"0`````
MB<''1"0L`````,'A'@^LT`*+5"0DB<N+C"20`@``"<.+1"1`@<'6P6+*B5PD
M0`'(BTPD.#'9,<V)Z0'!BT0D(,'@!8E$)"B+1"0@BVPD*`^LT!N+5"0TQT0D
M-`````")1"1(BT0D,`ML)$@!Z8E,)"B)3"1(B<$/K-`"BU0D+,'A'HG-BXPD
MF`(```G%BT0D.('!UL%BRHEL)#@!R(M,)$`QZ8G-,?6)Z0'!BT0D*(G&B<>+
M1"0@P>8%#ZS7&XET)#"+="0P"?X!\8G&P>8>B4PD6(E,)#"+5"0DB?&)QHM\
M)#3'1"0D``````^LU@*+5"0LQT0D+`````")\(G."<:+1"1`B?6+M"2@`@``
MB6PD0('&UL%BR@'PBW0D.#'NBVPD2#'UBW0D,(GIB?T!P8GPB??!X`4/K.\;
MB40D((MT)""+1"0H"?X!\8E,)"")SHG!#ZS0`L'A'HM4)"0)P8M$)#B)S8N,
M)*@"``");"0X@<'6P6+*`<B+3"1`,>F+;"18,<V)Z0'!BT0D(,'@!8E$)"B+
M1"0@BVPD*`^LT!N+5"0TB40D2(M$)#`+;"1(`>F)3"1(B4PD*(G!#ZS0`L'A
M'HG-BXPDL`(```G%BT0D0(M4)"S'1"0T`````('!UL%BRHEL)$`!R(M,)#@Q
MZ8G-,?6)Z0'!BT0D*(G&B<>+1"0@P>8%#ZS7&XM4)"3'1"0D`````(ET)#"+
M="0P"?Z+?"0T`?&)QL'F'HE,)%B)3"0PB?&)Q@^LU@*+5"0LB?")S@G&BT0D
M.(GUB[0DN`(``(EL)#B!QM;!8LH!\(MT)$`Q[HML)$@Q]8MT)#")Z8G]`<&)
M\(GWP>`%#ZSO&XE$)""+="0@BT0D*`G^`?&)SHE,)"")P0^LT`+!X1X)P8M$
M)$")S8N,),`"``");"1`@<'6P6+*`<B+3"0X,>F+;"18,<V)Z0'!BT0D(,'@
M!8E$)"B+1"0@BU0D)(ML)"C'1"0L``````^LT!N+5"0TQT0D-`````")1"1(
MBT0D,`ML)$@!Z8E,)$B)3"0HB<$/K-`"BU0D+,'A'HG-BXPDR`(```G%BT0D
M.('!UL%BRHEL)#@!R(M,)$`QZ8G-,?6)Z0'!BT0D*(G&B<>+1"0@P>8%#ZS7
M&XM4)"2)="0PBW0D,`G^BWPD-`'QB<;!YAZ)3"0PB4PD6(GQB<8/K-8"B?")
MS@G&BT0D0(GUB[0DT`(``(EL)$"!QM;!8LH!\(MT)#@Q[HML)$@Q]8MT)#")
MZ8G]`<&)\(GWP>`%#ZSO&XE$)""+="0@"?X!\8E,)""+1"0HB<Z+5"0LBYPD
MW`(``,=$)"0`````B<''1"0L``````^LT`+!X1X)P8M$)#B)S8N,)-@"``")
M;"0X@<'6P6+*@],`,=(!R(M,)$`1VC';,>F+;"18,<V)Z0'!BT0D(!'3BU0D
M),'@!8E$)"B+1"0@BVPD*`^LT!LQTHE$)$B+1"0P"VPD2`'I$=.)3"0HBU0D
M-(E,)$B)P<'A'@^LT`*)7"1,BYPDY`(``(G-BXPDX`(```G%BT0D0('!UL%B
MRHEL)$"#TP`QT@'(BTPD.!':,=LQZ8G-,?6)Z0'!BT0D*!'3BU0D+(G&B<?!
MY@4/K-<;,=*)="0PBW0D,`G^`?$1TXE,)%B)7"1<BT0D((M4)"2)3"0PB<;'
M1"0T`````(M\)#3!YA['1"0D`````(GQB<8/K-8"BU0D+(GPB<X)QHM$)#B)
M]8NT).@"``");"0X@<;6P6+*`?"+="1`,>Z+;"1(,?6+="0PB>F)_0'!B?")
M]\'@!0^L[QN)1"0@BW0D(`G^B?`!R(E$)""+1"0HB<$/K-`"BU0D,,'A'@G!
MB=:+1"1`B<V+3"0TP>8>B70D*(MT)%B)SP^DUQX/K,H"P>D"B50D,(M4)"2)
M3"0TBXPD\`(``(E\)"R!P=;!8LH!R(M,)#@QZ3'.B?$!P8M$)"")Q@^LT!N)
M1"1`P>8%"W0D0,'J&XGPB50D1`'(B<$#3"00BT0D:(MT)"B)"(G!QT`$````
M`(M$)!@#1"0@"W0D,,=!#`````")00B)\`,$)(E!$(GH`T0D"(E!&(M$)#@#
M1"10QT$4`````,=!'`````")02#'020`````BX0D_`(``&4S!10```!U"X'$
M#`,``%M>7UW#Z*H?``"-M"8`````C78`55=64^A'UO__@<.'C@``@^P<A<`/
MA)X```"+BQP!``"+"8E,)`B%R0^$B@````^V"(3)=`6`^3UU1C'VBWPD"(LO
MA>UT+XE4)`R)1"0$9I"#[`16_W0D#%7HTM+__X/$$(7`=0>`?#4`/70L@\<$
MBR^%[77;@\0<B>A;7E]=PY")QH/&`0^V#H3)=`6`^3UU\2G&ZZ>-=@"+1"0,
MB?HK5"0(C6PU`<'Z`HD0@\0<B>A;7E]=PXUV`(/$'#'M6XGH7E]=PXVT)@``
M``"-="8`D.APUO__@<*[C0``5U:)QE.#[!!EH10```")1"0,,<"+NAP!``"-
M7"0(B=J)\.C^_O__A<!T,XM4)`B+!XT$D(M0!(D0A=)TX8VT)@````"0@\`$
MBU`$B1"%TG7TB=J)\.C+_O__A<!US8M$)`QE,P44````=0>#Q!!;7E_#Z$X>
M``"-M"8`````C;0F`````%6)Q5=6B=93Z./4__^!PR.-``"#[#AEH10```")
M1"0H,<`QP(`Z/0^4P`'&5NA.T/__@\00B40D!(U4)!B)Z.A<_O__A<`/A`0!
M``"#[`R)QU#H*=#__X/$$#M$)`0/@]0```"+1"08C12%`````(N#'`$``(D$
M)`^V10"$P`^$G`$``#P]#X24`0``B>AFD(/``0^V"(3)=`6`^3UU\2GHBPPD
M@^P,BSD!UXM4)!"-1!`"4.AGT/__@\00B0>%P`^$;0$``(L,)(M4)!B+`8U-
M`8L4D`^V10"(`CP]=!V$P'4)ZQ>-=@`\/700@\$!#[9!_X/"`8@"A,!U[,8"
M/3'`C;0F``````^V#`:(3`(!@\`!A,EU\3'`BUPD'&4S'10````/A1,!``"#
MQ"Q;7E]=PXVV`````#'`C;8`````#[84!H@4!X/``832=?+KQXN#'`$``(L(
MB00DBSF%_P^$P@```#'`ZPF-M"8`````B?B->`&+%+F%TG7TC02%#````(N3
M<!$``(72=6N)3"0(@^P,4,>#<!$```$```#H?,___X/$$(7`#X2$````@^P$
MC12]`````%*+3"00B50D%%&)1"044.BSS___BU0D$(M$)!B#Q!")`HM4)`R+
M1"0(QT2X!`````")?"08Z87^__^-="8`D(/L"%!1Z`[-__^+5"00B40D&(/$
M$(D"A<!T((T4O0````#KPHUT)@`QP.EZ_O__N`@````Q_^E0____N/_____I
MW/[__^C^&P``C;0F`````(VT)@````!5B<575E/HE=+__X'#U8H``('LC```
M`&6A%````(E$)'PQP(7M=`:`?0``=2.+1"1\93,%%`````^%.P$``('$C```
M`%M>7UW#C;0F`````(/L#%7H=\W__XE$)!"#Q!"%P'3)C8,YH?__B40D!(V#
M.*'__XE$)`B#[`S_="0,Z(S-__^#Q!"%P`^$P0```(U0$XM\)`2Y`@```(G6
M\Z8/E\`<`(3`=-"+?"0(N0,```")UO.F#Y?`'`"$P'2ZB50D#(/L#%7H9<W_
M_XM4)!R)QHD4)(E4)!SH4\W__XU$!@*)!"3HY\W__XG&6(V#.Z'__UJ+5"04
M4E50:O]J`5;H7,[__X/$'(U$)"!05FH#Z+S+__^#Q!"#^/]T$(M$)"PE`/``
M`#T`0```=$2#[`Q6Z`O-__^#Q!"#[`Q6Z%_,__^#Q!#I+____XVT)@````"#
M[`S_="0,Z#3-__^)+"3HG,W__X/$$.G!_O__C70F`(GPZ(G^___KO^AR&@``
M9I!6B<93Z!?1__^!PU>)``"#['AEH10```")1"1P,<"-1"004%9J`^@%S/__
M@\00A<!U-HM4)!R!X@#P``"!^@!```!T"('Z`*```'4>@^P(:@)6Z.G+__^#
MQ!"%P`^4P`^VP.L&C70F`#'`BTPD;&4S#10```!U!H/$=%M>P^CN&0``C;0F
M`````(VT)@````!55XG'5E/HA=#__X'#Q8@``('L,!```(E4)`QEH10```")
MA"0@$```,<!H_P\``(V#0:'__XUT)"164.C0S/__@\00A<!^<8UH_XN3_```
M`(!\+!P`BQ)U5X7M=&.)5"0,@^P$56HO5NCSS/__@\00BU0D#(7`=$B#[`Q2
MZ-_*__]55E=0Z,;+__^#Q""+A"0<$```93,%%````'4_@<0L$```6UY?7<.-
MM"8`````D(G%ZZF-="8`BX/\````BQ"#[`Q2Z)?*__^#Q`S_="0,5U#H6<K_
M_X/$$.NQZ/\8``"-M"8`````C;0F`````)!3Z)K/__^!P]J'``"#[!2+@_P`
M``#_,.A4RO__C9,TH___4HV34*'___^S$`$``%)0Z&K,__^#Q"A;PXUT)@"0
M5E/H6<___X'#F8<``(/L$(NS_````/\VZ!/*__^)!"3HF____UC_-N@#RO__
M6HV3Y:+__UEJ`%)2C9-PC/__4HV3;*'__U)0Z&/*__^#Q"1;7L.-M"8`````
MC;8`````55=64^CWSO__@<,WAP``@>P<(```9:$4````B80D#"```#'`Z(?(
M__^#[`B-DTRA__]24(V#@:'__U!H`1```&H!C70D)E;H=,O__X/$'&@`$```
MC;PD$Q```%=6,?;H',O__X/$$(7`>"F#[`R)Q8U``5#HM\K__X/$$(G&A<!T
M$H/L!%574.CSR?__Q@0N`(/$$(N,)`P@``!E,PT4````B?!U"X'$'"```%M>
M7UW#Z)H7``"-M"8`````C78`Z3O___^-M"8`````C70F`%575E/H)\[__X'#
M9X8``('LG!```(N\)+`0``"+M"2T$```B7PD$&6A%````(F$)(P0```QP(U$
M)"R)1"04B<*-@XVA___HE??__X/L"&HOB<57Z!C(__^#Q!"%P'0YBWPD$(V#
MEJ'__XGZZ-#X__^)^(N,)(P0``!E,PT4````#X5Z`0``@<2<$```6UY?7<.-
MM"8`````@^P,_W0D'.@<R?__6EF)1"0@C8.CH?__B40D%%!6Z.7)__^#Q!")
MQHV#.:'__XE$)!R-M@````"%]G2+@#X`#X3#````A>UT%8/L"%95Z'7*__^#
MQ!"%P`^$BP```(/L#%;HP<C__X/$$(!\!O\O=16-M"8`````@^@!@'P&_R_&
M!`8`=/*+5"08C400`3W_#P``#X\N____@^P$C8.EH?___W0D%%"-@Z"B__]6
M4&@`$```:@&-M"2H````5NB5R?__@\0<_W0D&%9J`^CVQO__@\00A<!U$(M$
M)#PE`/```#T`@```=$^#[`C_="04:@#H$<G__X/$$(G&Z3?___^-M"8`````
MA>UT'(M\)!RY`@```(GN\Z8/E\`<`(3`=,>-M@````"+="0<N`$```#I4/__
M_V:0@^P(:@%6Z'7'__^#Q!"%P'6?B?*-@Y:A___H4??__X/L#%;H6,G__X/$
M$.ER_O__Z'L5``"-M"8`````C70F`(M4)`0/M@J)T(3)=!N-=@"#P@&`^2\/
MM@H/1,*$R77PPXVT)@````##C;0F`````%93Z.G+__^!PRF$``"#[`2+="00
MA?8/A*0```"`/@`/A)L```"#[`Q6Z%+'__^#Q!"-1`;_.<9R#NLAC70F`)"#
MZ`$YQG09@#@O=/3K!V:0@#@O=#"#Z`$YQG+T.<9U)8`X+W1;@^P,C8.EH?__
M4.B<R/__@\00@\0$6U[#C78`@#@O=0>#Z`$YQG+T*?"-2`*)PC'`@?D`$```
M=QN-0@%H`!```%!6C;-P`0``5N@MQ?__@\00B?"#Q`1;7L-FD(/L#(V#.:'_
M_U#H0<C__X/$$(/$!%M>PXVT)@````"05U93Z`C+__^!PTB#``"#[#!EH10`
M``")1"0L,<"-="0$BX,0H___B40D"HN#%*/__XE$)`Z+@QBC__^)1"02BX,<
MH___B40D%HN#(*/__XE$)!J+@R2C__^)1"0>BX,HH___B40D(HN#+*/__XE$
M)"8/MX,PH___9HE$)"J-@Z>A___H"/7__XV#L*'__^C]]/__C8.XH?__Z/+T
M__^-@\&A___HY_3__XV#R*'__^C<]/__C8/8H?__Z-'T__^-@XVA___HQO3_
M_XV#Y*'__^B[]/__C8/NH?__Z+#T__^-@_BA___HI?3__XV#EJ'__^B:]/__
MB?*-@P*B___HO?/__X7`=`V)PHV#[J'__^@,]?__B?*-@Q.B___HG_/__X7`
M=`V)PHV#):+__^CN]/__B?*-@S"B___H@?/__X7`=#6)PHV#C:'__^C0]/__
MC9-<HO__C8/(H?__Z+_T__^+1"0L93,%%````'5=@\0P6UY?PXUV`(GRC8-`
MHO__Z#OS__^%P'07B<*-@^2A___HBO3__^NXC;0F`````)"-="0;N0H```"-
MNU&B___SI@^7P!P`A,!UEHU4)"6-@^2A___H5_3__^N%Z)`2``!3Z#K)__^!
MPWJ!``"#[!AEH10```")1"0,,<"+@S@!``"#^/]T&HM,)`QE,PT4````=3Z#
MQ!A;PXVT)@````"0C50D"(V#Y*'__^BA\O__B<(QP(72=!(/MA*`^C`/E<$Q
MP(32#Y7`(<B)@S@!``#KM>@:$@``C;0F`````(UV`%/HNLC__X'#^H```(/L
M".A\Q/__@^P,4.A3Q/__@\00A<!T#(L`@\0(6\.-="8`D(/$"#'`6\.-M"8`
M````9I!55U93Z'?(__^!P[>```"#[!QEH10```")1"0,,<"-5"0(BWPD,(V#
M7J+__^C_\?__A<!T!X`X`(G&=22)^HV#7J+__^A'\___BT0D#&4S!10```!U
M:X/$'%M>7UW#9I"#[`A74.@VQ/__@\00A<!UV(/L#%?HEL/__XDT)(G%Z(S#
M__^-1`4"B00DZ"#$__^#Q`R)Q8V#HZ'__U90C8.@HO__5U!J_VH!5>B1Q/__
M@\0@B>J-@UZB___HT?+__^N(Z`H1``"-M"8`````C78`Z*#(__^!PNM_``!5
M5U93@>R,@0``B=&+A"2@@0``B50D"(UT)#"-F6ZB__^)1"049:$4````B80D
M?($``#'`C8)ZHO__B9PDG````(F$))````"-@CFA__^-DB6B__^)A"24````
MC8$>HO__B80DK````(V!?Z+__XF$)+````"-@3NB__^)A"2T````C8&'HO__
MB80DN````(V!BZ+__XE4)!")E"2H````B?*)A"2@````C8&-H?__QX0DF```
M``````#'A"2\`````````,>$)*0`````````Z(#P__^%P'0)@#@`#X7S!```
MZ/[]__^)Q87`#X1T!```@^P,58M\)!B)^^@UPO__C40``8D$).C)PO__B40D
M'(/$$(!]``!T1HM$)`B+?"0,B70D((V`E*+__XG^B<>-M@`````/MD4`@^P,
M@\4!4%=J_VH!5HM<)"B#Q@+H$\/__X/$((!]``!UVHMT)""-G"2H````BT0D
M$.L6C;0F`````&:0@\,$BP.%P`^$DP$``(GRZ,SO__^)QX7`=.:`.`!TX>CL
M]/__A<!TV(/L#%>+7"08Z!O#__^#Q!")Q87`#X1>`0``C;8`````B>F+$8/!
M!(V"__[^_O?2(=`E@("`@'3JB<+!ZA"I@(````]$PHU1`@]$RHG"`,*+5"0,
M@]D#*>F+&H/"!(V#__[^_O?3(=@E@("`@'3JB</!ZQ"I@(````]$PXU:`@]$
MTXG#`,.#V@,K5"0,@^P,C;P1!`0``%>+7"08Z)C!____="0<BTPD'(G"C8&9
MHO__B<M0C8&EH?__B40D*%"-@9ZB__]54&K_:@&)5"0X4NCTP?__@\0H:,`!
M``#_="08Z..^__^#Q!"#^/]U$.BVOO__BP"#^!$/A10#``"#[`16_W0D%&H#
MBUPD&.@(P/__@\00B<6%P`^$JP```(/L#/]T)!B+1"0D_S"+7"0<C8-\H___
M4(N#&`$``&H!_S#HU+[__X/$(,=$)"``````BXPD?($``&4S#10```"+1"0@
M#X5#"0``@<2,@0``6UY?7<.-M@`````Q_XVV`````(N<O)````"%VW0U@#L`
M=#")V(/'`>A.\___A<!TXH/L#%.+7"08Z'W!__^#Q!"%P'3.B<7I9_[__XVT
M)@`````Q[>E9_O__D(M$)$`E`/```#T`0```#X5!____BT0D2(M<)`B)1"0@
MZ.N___\Y1"0@#X4F____BT0D0"7_`0``/<`!```/A1+___^#[`Q7BWPD&(G[
MZ![`__^)\HE$)#"-AVFB___HC>W__X/$$(7`#X12`@``@^P,4(M<)!CHY<#_
M_UI94(M$)"#_,.B']?__B40D*(/$$(7`#X0H`@``@^P,BWPD)%>+7"08Z">_
M__^#Q!"#^`-V/XM4)`B-=`?\B?NY!0```(VZIZ+___.F#Y?"@-H`A-)U'H/X
M!`^$J`8``(!\`_LO#X2=!@``C;0F`````(UV`.@+^O__A<!U(8/L"&H`_W0D
M)(M<)!CH)<#__XE$)#2#Q!"%P`^%M0$``(M\)`B-EURB__^)^XV'Y*'__^@?
M[O__C;?EHO__Z+2\__]64(V'P*+__XV_SJ+___]T)!C_="084&K_:@'_="0\
MZ*"___^#Q"")="04BW0D(.M`C78`BUPD".AGO/__@S@1=4F+7"0(@\4!Z&:\
M__^#[`S_="0@55#_="0H_W0D*%=J_VH!5HM<)#CH5K___X/$,(/L"&C``0``
M5HM<)!CH0;S__X/$$(/X_W2I@^P,_W0D&(M\)!B)^^AGO?__BUPD,(V'C:'_
M_XG:Z&;M__^)'"3HSOG__X/$$.F-_?__C;8`````B=@Q_^L1C;0F`````(UV
M`(N$O)P```"%P'1^B?*#QP'HR^O__X7`=.>`.`!TXH/L#%"+7"08Z"6___^#
MQ!"%P'3.B<7I0_O__X/L"%#_="08BT0D)/\PBUPD'(V#0*/__^D&_?__C;0F
M`````(UV`(/L#%")1"0<Z$/Y__^+1"0<BUPD&(D$).C3OO__B40D,(/$$.GN
M_/__@^P,:@V+?"08B?N-KW.B___HP;W__XE$)!R#Q!#I^?K__XUT)@"0BT0D
M%(L`B40D&.G)_?__:@)J_VKNBW0D,%:+?"08B?OHN[O__X/$#&H&C80DA`$`
M`(E$)!Q05N@DO/__@\00@+PD?`$```!U#H"\)'T!``!##X1!!0``:@!J`&H`
M_W0D,(M<)!CH=KO__\>$)-`````!(T5GQX0DU`````````#'A"38````B:O-
M[\>$)-P`````````QX0DX````/[<NIC'A"3D`````````,>$).@```!V5#(0
MQX0D[`````````#'A"3P````\.'2P\>$)/0`````````QX0D^`````````#'
MA"3\`````````,>$)``!````````QX0D!`$```````#'A"1(`0```````(/$
M$(V$),````")1"0LC80D^````(E$)"B-M"8`````D(/L!&@`@```_W0D'/]T
M)#"+7"08Z!>[__^#Q!")QH7`#X[C`0``B?")\8ET)!B+O"3P````F<'A`[@`
M`````XPDZ````#N,).@````;A"3L````B50D'(NL)/0```!S!H/'`8/5`(M4
M)!R+1"08B8PDZ````,>$).P`````````#ZS0'<'J'0'XB80D\````(N$)#@!
M```1ZHF4)/0```"%P`^$6`$``+U`````*<4Y[@].[@-$)"B#[`15_W0D'%"+
M7"08Z`:[__^+A"1(`0```>B)A"1(`0``@\00@_A`#X4:____BT0D+"GN`VPD
M%.A;P/__@_X_#X[M`@``@^Y`B?>)="08B>[![P:-7P'!XP8!ZXML)"R-M"8`
M````D(L&@\9`B80D^````(M&Q(F$)/P```"+1LB)A"0``0``BT;,B80D!`$`
M`(M&T(F$)`@!``"+1M2)A"0,`0``BT;8B80D$`$``(M&W(F$)!0!``"+1N")
MA"08`0``BT;DB80D'`$``(M&Z(F$)"`!``"+1NR)A"0D`0``BT;PB80D*`$`
M`(M&](F$)"P!``"+1OB)A"0P`0``BT;\B80D-`$``(GHZ(>___\Y\P^%3___
M_XMT)!C!YP8I_FI$5E/_="0TBUPD&.@EN?__B;0D2`$``(/$$.D&_O__C;8`
M````BVPD%.GL_O__@^P,_W0D,(M<)!CH-[K__XN$)/@```"+E"3\````BZPD
M^````(NT)``!```/K-`#@^`_#\T/SHU(`<:$!`@!``"`@\00@_DX#XZ;`0``
MBU0D*+A``````<HIR(G!=`TQP,8$`@"#P`$YR'+UBT0D+.C2OO__BWPD*+D.
M````,<#SJXM$)"R)M"0P`0``C;PD>P$``(VT)$`!``")K"0T`0``Z*"^__^+
ME"3`````C8PD4P$``(E\)!2)3"08B<V+3"0(B?</RHF4)#\!``"+E"3(````
MC8F4HO__#[:$),,````/RHF4)$,!``"+E"30````B<X/RHF4)$<!``"+E"38
M````#\J)E"1+`0``BY0DX`````_*B90D3P$``.L-C;0F``````^V!X/'`8/L
M#`^VP%!6:O]J`56+7"0H@\4"Z,&Y__^#Q"`Y;"04==B+7"0(QH0D>P$```"-
M@^6B__]0C8.QHO___W0D'/]T)!C_="084&K_:@'_="0\Z(6Y__^#Q"#I1/K_
M_XM$)!2+4`2%T@^$7OG__X/L#%*+?"08B?N)5"0DZ"NX__^#Q!"#^`,/AC_Y
M__^+5"04N04```"-OZRB__^-=`+\\Z8/E\`<`(3`#T54)!B)5"08Z17Y__^)
MZ^GH_?__NC@```"+1"0H,=LIR@'(@_H$<RJ%T@^$??[__\8``/;"`@^$<?[_
M_S')9HE,$/[I9?[__XVT)@````"-=@"-2`3'``````"#X?S'1!#\`````"G(
M`="#X/R#^`0/@C?^__^#X/PQTHD<$8/"!#G"<O;I(_[__X"\)'X!``!!#X6Q
M^O__@+PD?P$``$,/A:/Z__^`O"2``0``2`^%E?K__X"\)($!``!%#X6'^O__
M:@)J_VK&BVPD,%6+?"08B?OH^K7__X/$#&HIBW0D'%95Z&JV__^-A^6B__]0
MC8>QHO__5O]T)"C_="0H4&K_:@'_="1,Z":X__^#Q##IY?C__^BI!```C;0F
M`````&:055=64^A'N___@<.'<P``@^PX9:$4````B40D*#'`B[O\````_S?H
M];7__UW_-XG&Z.NU__\/ME9HB%!IC40D*(E$)!R)PHV#R*'__^BOY/__@\00
MA<!T"8`X,0^$KP(``.C:[___@^P,_S?HL+7__XV3WZ+__VH+:@%24.A?M?__
M@\0@A<`/A/X```"+0`R#NW@1```!BR^+0!B)1"0(#X[G````,?;K/8VT)@``
M``"+0@R#[`B-5@%0BX-T$0``_S20B50D%.BTM___@\00BXMX$0``A<!U;X/&
M`HM4)`0Y\8G6?F*#[`Q5Z#&U__]J`%;_="0@4.@TMO__@\0@A<!T/8L0BR^+
M0@@E``0@`#T`!```=)J)5"0$@^P,5>C]M/__:@)J`(M4)!Q24.ANM___BR^#
MQ"#I=____XUT)@"+BW@1``"++XU!_SGP=3V#^0%^.(GHO@$```"+;"0(ZPF-
MM"8`````BP>#[`R#Q@%0Z*JT__]:6550Z%&T__^#Q!`YLW@1``!_WHLO@^P,
M5>B+M/__C9/DHO__:@-J`5)0Z#JT__^#Q"")QH7`=#*+0`R#[`R+*/\WZ&*T
M__^#Q`R-D^:B__]255#H(;3__XM&#(/$$(LP]D8*0`^%9P$``(/L#/\WZ#6T
M__^-D^NB__]J`VH!4E#HY+/__X/$((G&A<!T-HM4)`R-@Y:A___H[.+__XG%
MA<`/A`(!``"+1@R#[`R+,/\WZ/.S__^#Q`Q55E#HN+/__X/$$(/L#/\WZ-NS
M__^#Q`R-D^VB__]J`5)0Z-FR__^)QEC_-^B_L___@\0,C9,"H___4E90Z'ZS
M__]:_S?HIK/__XM4)!S&0&D`C8.-H?__Z'/B__^#Q!")QHF#?!$``(7`=$2#
M[`AHP`$``%;H9K+__X/$$(U0`8/Z`78)@_@1#X6J````BT0D'&4S!10````/
MA90```"#Q"Q;7E]=PXVT)@````!FD(/L#/^S=!$``.BR\/__@\00B<:)@WP1
M``"%P'6?@^P,C8/0H___4.CDM/__C70F`(!X`0`/A$S]___I0OW__Y"+@W01
M``"#[`R+*(M&#(LP_S?HZ;+__XGJB?#H@.?__X/$$.GS_O__@^P,_S?HSK+_
M_UE=5E#H-;3__X/$$.E^_O__Z#@!``!0BX-T$0``5O\PC8/TH___4.ARM/__
M9I!7Z'````"!QPIP``!64XM<)!"#[`Q3Z,7K__^#Q!`/MA")QH32=!F-M"8`
M````9I"#P`&`^B\/MA`/1/"$TG7PZ$ON__^%VW0?A<!T&X`[`'06N00```"-
MOYFB___SI@^7P!P`A,!T!%M>7\.)V%M>7^FZY/__BSPDPV:09I!FD%575E/H
M1[?__X'#AV\``(/L#(ML)"CHI;#__XVS]/[__XV#\/[__RG&P?X"=!\Q_X/L
M!%7_="0L_W0D+/^4N_#^__^#QP&#Q!`Y_G7C@\0,6UY?7<.-M"8`````C70F
M`,-FD&:09I!FD&:09I!FD)!3Z-JV__^!PQIO``"#[`C_LS0!``#_="0<_W0D
M'/]T)!SH"K'__X/$&%O#9I!FD)!3Z*JV__^!P^IN``"#[`CH[++__U.#[`CH
MD[;__X'#TVX``(/$"%O#````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````#`````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,
M;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O
M<')O8R\E:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"
M`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?
M4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/
M0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)
M0E)!4EE?4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%5315).
M04U%`"4P,G@`<&%R+0`E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S
M)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L
M`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-#<`+64`+2T```!?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````!P97)L>'-I+F,````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O
M;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI
M('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I
M;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS
M=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR
M;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-
M4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%
M(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD[
M"G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q
M,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P
M-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@
M+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C
M;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E
M<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'
M24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X
M92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_
M("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T
M7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO
M8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D
M<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D
M<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED
M>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E
M="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E
M96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E
M860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@
M(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I
M9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X
M(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@
M,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*
M)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR
M96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K
M*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B
M=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68[
M"F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@
M)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@
M)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M
M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D
M97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@
M)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA
M;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL
M;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD
M(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T
M96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")3
M2$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD
M9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]
M("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R
M968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E
M("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E
M86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO
M9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.
M0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@
M*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI
M('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*
M8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E
M:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA
M;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA
M;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I
M92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR
M971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO
M="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S
M7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R
M7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE
M*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%
M55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL
M97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'
M5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T
M7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@
M("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI
M.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF
M="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]
M"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN
M8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P
M:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`
M861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U
M<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R
M9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L
M<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H
M)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@
M)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N
M("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO
M9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D
M,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S
M($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE
M>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D
M;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E
M9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J
M,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@
M9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]
M"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O
M+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=
M*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R
M(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E
M9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X[
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D
M,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V
M86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@
M)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U
M8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N
M("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@
M)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE
M9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U
M;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D[
M"FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE
M(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF
M;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I
M.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE
M;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@
M)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O
M6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A
M=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK
M.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F
M:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D
M8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@
M(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E
M;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?
M5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!
M4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT
M+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B
M*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R
M("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@
M)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-
M1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ
M4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE
M*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^
M861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D
M8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE
M("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?
M;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM
M;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ
M1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D
M;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,
M:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z
M:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[
M4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN
M="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X
M="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@
M)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]
M?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]
M>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL
M93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M
M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC
M;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?
M;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B
M*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE
M(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA
M;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2
M.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T
M97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS
M,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E
M<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E
M(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E
M<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER
M92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2![
M"B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H
M"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2
M(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@
M=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T
M:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@
M9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97
M:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I
M;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]
M("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@
M?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<
M5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G
M;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE
M;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII
M9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@
M)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D
M8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P
M<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I
M.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@
M*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H
M+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M
M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO
M<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO
M9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T
M96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G
M;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.
M5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*
M?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N
M86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345]
M(&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2![
M"FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF
M("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2![
M"B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D
M14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG
M>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*
M?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D
M*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I
M(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R
M;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W
M9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)
M5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!
M4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID
M96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0
M($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,
M7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@
M*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D
M=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR
M971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B
M0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN
M8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@
M;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L
M:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E
M;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N
M<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R
M7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T
M("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N
M;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D
M,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF
M("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D
M,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`!&P,[
M\````!T```#D8/__#`$``+1D__\P`0``Q&3__S`-``!4:/__1`$```21__^(
M`0``U)'__P`"``!DDO__.`(``+24__^X`@``-);__W`#``#$EO__P`,``+27
M__]<!```])?__XP$``!4F/__V`0``!29__]H!0``))G__WP%```TF___9`8`
M`&2;__]X!@``1)S__^@&```4GO__(`<``)2>__]$!P``U)[__W@'``"DG___
MY`<```2L__]T"P``A*___^@,``#ZK___>`T```2P__^,#0``9+#__]@-``!T
ML/__[`T``*2P__\8#@``%``````````!>E(``7P(`1L,!`2(`0``(````!P`
M``#07___T`,````."$8.#$H/"W0$>``_&CLJ,B0B$````$````!\8___"```
M``````!`````5`````AG__^F*````$$."(4"1`X,AP-!#A"&!$$.%(,%1@Z@
M!@./*`H.%$'##A!!Q@X,0<<."$'%#@1!"P```'0```"8````=(___\0`````
M00X(A0)!#@R'`T$.$(8$00X4@P5.#C`"00XT00XX1`X\00Y`2`XP5PH.%$/#
M#A!!Q@X,0<<."$'%#@1""VX*#A1#PPX00<8.#$''#@A!Q0X$1`M##A1#PPX0
M0\8.#$''#@A!Q0X$`#0````0`0``S(___X(`````3`X(AP)!#@R&`T,.$(,$
M0PX@`F8*#A!!PPX,0<8."$''#@1!"P``?````$@!```DD/__0@(```!!#@B%
M`D,.#(<#00X0A@1##A2#!4X.3%<.4$@.0%H.3$,.4$@.0`)-#DQ-#E!(#D`"
M<0H.%$'##A!!Q@X,0<<."$'%#@1'"P)<#DQ!#E!2#D!+#D1(#DA)#DQ%#E!0
M#D!C#DA!#DQ!#E!0#D````"T````R`$``/21__]^`0```$$."(4"0PX,AP-!
M#A"&!$$.%(,%40Z@`6T*#A1!PPX00<8.#$''#@A!Q0X$2`M##JP!00ZP`4P.
MH`%;#JP!1`ZP`4@.H`%^#JP!00ZP`68.K`%'#J@!10ZL`4$.L`%!#K0!0@ZX
M`4(.O`%!#L`!2`ZD`44.J`%!#JP!0@ZP`4@.H`%8#JP!00ZP`4@.H`%##JP!
M00ZP`4@.H`%/#JP!1`ZP`5`.H`$`3````(`"``"\DO__@@````!!#@B&`D,.
M#(,#3@Z$`5$.B`%!#HP!0@Z0`4@.@`%A#H@!0@Z,`4$.D`%(#H`!8`H.#$'#
M#@A!Q@X$00L```"8````T`(``/R2___A`````$$."(4"00X,AP-##A"&!$$.
M%(,%40[$(%@.R"!+#LP@00[0($@.P"!A#L0@00[(($(.S"!!#M`@2`[`($L.
MS"!!#M`@1@[4($$.V"!!#MP@00[@($@.P"!6"@X40<,.$$'&#@Q!QPX(0<4.
M!$D+4P[,($$.T"!(#L0@1`[(($$.S"!!#M`@2`[`(``L````;`,``%"3__\[
M`````$$."(,"3@X<2`X@3`XD3`XH00XL00XP2`X(0<,.!`!(````G`,``&"3
M__]3`````$$."(8"00X,@P-.#AQ(#B!.#AQ"#B!&#AQ'#AA"#AQ!#B!!#B1'
M#BA'#BQ!#C!(#@Q!PPX(0<8.!```C````.@#``!TD___M@````!!#@B%`D$.
M#(<#00X0A@1!#A2#!5$.L$!7#KA`1PZ\0$$.P$!'#L1`10[(0$(.S$!%#M!`
M2`ZT0$4.N$!(#KQ`00[`0$H.L$!'#KQ`1@[`0$@.L$!)#K1`00ZX0$$.O$!!
M#L!`3`ZP0%@*#A1!PPX00<8.#$''#@A!Q0X$00L`$````'@$``"DD___!0``
M``````#D````C`0``*"3__\%`@```$$."(4"00X,AP-!#A"&!$$.%(,%40ZP
M(7D.N"%"#KPA0P[`(4@.L"%Q"@X40<,.$$'&#@Q!QPX(0<4.!$@+0PZ\(40.
MP"%&#KPA00ZX(4\.O"%!#L`A2`ZP(68.N"%!#KPA00[`(4@.L"%+#KPA00[`
M(4@.L"%R#K0A2@ZX(4$.O"%'#L`A00[$(44.R"%"#LPA2`[0(4@.M"%$#K@A
M00Z\(4(.P"%(#K`A5PZX(40.O"%"#L`A2`ZP(0)!#K@A0@Z\(4$.P"%(#K`A
M5`Z\(4$.P"%(#K`A$````'0%``#(E/__*0````````!L````B`4``.24___8
M`````$$."(8"00X,@P-.#A!8#AQ!#B!(#A!W#AQ'#B!(#A!#"@X,0<,."$'&
M#@1$"V4.%$$.&$$.'$<.($@.$$4*#@Q!PPX(0<8.!$,+0PX<1PX@2`X00PX,
M0<,."$'&#@0`-````/@%``!4E?__T`$```!!#@B'`D$.#(8#00X0@P1.#D`#
M8`$*#A!!PPX,0<8."$''#@1$"P`@````,`8``.R6__]V`````$$."(,"3@X@
M9PH."$'##@1)"P`P````5`8``$B7__\W`````$$."(,"3@X02`X<00X@2`X0
M20H."$'##@1&"T,."$/##@0`:````(@&``!4E___Q@````!!#@B%`D$.#(<#
M00X0A@1!#A2#!4X.,`)'"@X40<,.$$'&#@Q!QPX(0<4.!$,+0PXX00X\00Y`
M2`XP1PX\00Y`7@XT20XX00X\1PY`00Y$0@Y(0@Y,00Y02`XPC`,``/0&``"X
ME___5PP```!,#@B%`D$.#(<#00X0A@1!#A2#!48.H(,"`NH.K(,"00ZP@P)>
M#J"#`FD.K(,"1`ZP@P)!#K2#`D(.N(,"0@Z\@P)!#L"#`D\.H(,"`DL.K(,"
M00ZP@P),#J"#`@)_#JR#`D@.L(,"30ZT@P)/#KB#`DL.O(,"1P[`@P)!#L2#
M`D(.R(,"0@[,@P)%#M"#`D@.J(,"10ZL@P)$#K"#`D@.H(,"6`ZD@P)!#JB#
M`D0.K(,"0@ZP@P),#J"#`DT.K(,"1`ZP@P)&#K2#`DL.N(,"2`Z\@P)"#L"#
M`D@.H(,"9@H.%$'##A!!Q@X,0<<."$'%#@1'"VD.K(,"00ZP@P),#J"#`@)@
M#JR#`D$.L(,"7PZ@@P)+#JR#`D$.L(,"2@ZL@P)!#JB#`D$.K(,"1@ZP@P),
M#J"#`DL.K(,"10ZP@P),#J"#`@)0#JB#`D(.K(,"1`ZP@P)0#J"#`FL.I(,"
M00ZH@P)0#JR#`D0.L(,"00ZT@P)"#KB#`D(.O(,"1`[`@P)(#J"#`FH.K(,"
M1`ZP@P)!#K2#`D$.N(,"1`Z\@P)$#L"#`D$.Q(,"0@[(@P)"#LR#`D$.T(,"
M3`Z@@P)##JB#`D4.K(,"00ZP@P),#J"#`D@.K(,"1`ZP@P)G#J"#`GP.K(,"
M00ZP@P),#J"#`DX*#JB#`D$.K(,"1`ZP@P)&#K2#`ED+0PZL@P)!#K"#`F`.
MH(,"2`ZL@P)"#K"#`E@.H(,"6PZD@P)"#JB#`D(.K(,"10ZP@P).#J2#`D(.
MJ(,"3`ZL@P)!#K"#`D@.H(,"6@ZD@P)"#JB#`D(.K(,"1`ZP@P("L0Z@@P)A
M#J2#`D4.J(,"1`ZL@P)$#K"#`DP.H(,"`I\.I(,"00ZH@P)$#JR#`D$.L(,"
M7`Z@@P("_PZD@P)!#JB#`D$.K(,"1`ZP@P)3#J"#`E<.K(,"1`ZP@P)^#J"#
M`@+K#JR#`D0.L(,"00ZT@P)"#KB#`D(.O(,"00[`@P)/#J"#`ED.I(,"2@ZH
M@P)$#JR#`D0.L(,"00ZT@P)"#KB#`D(.O(,"1`[`@P)(#J"#`E<.K(,"00ZP
M@P)2#J"#`@+J#J2#`D(.J(,"0@ZL@P)%#K"#`DX.I(,"0@ZH@P)%#JR#`D$.
ML(,"3`ZT@P)'#KB#`D0.O(,"1`[`@P)!#L2#`D(.R(,"0@[,@P)$#M"#`D@.
MH(,"<`$``(0*``"(H/__?@,```!!#@B%`D$.#(<#00X0A@1!#A2#!4X.3%0.
M4$8.3$(.4&8.0%4.3$(.4$T.5$(.6$$.7$$.8$@.0'(.2$0.3$D.4$P.0%H.
M3$$.4$<.5$$.6$0.7$$.8$@.0%X.3$$.4$<.5$(.6$4.7$$.8$H.0'8.3$0.
M4$8.3$$.2$$.3$$.4$@.0$T.3$$.4$T.5$(.6$$.7$$.8$@.0$P.3$0.4$@.
M1$<.2$$.3$$.4$L.0$\.3$(.4$T.5$(.6$$.7$$.8$@.0&4.3$0.4$@.1$$.
M2$$.3$$.4$@.0$,.3$(.4$@.1$@.2$$.3$$.4$@.3$(.4$@.1$<.2$$.3$$.
M4$8.3$(.4%L.0$\.2$4.3$$.4$@.0&4*#A1!PPX00<8.#$''#@A!Q0X$2@M#
M"@Y,1@Y02`Y`3PY,1PY020M9#DQ)#E!1#D!(#DQ"#E!&#DQ!#DA!#DQ!#E!(
M#D!+#D1'#DA"#DQ'#E``1````/@+``"4HO__=@````!!#@B'`DP.#(8#00X0
M@P1'#AQ!#B!(#A`"2PK##@Q!Q@X(0<<.!$$+0\,.#$'&#@A!QPX$````1```
M`$`,``",5___3`(```!$#`$`1Q`%`G4`0Q`'`G5\1!`&`G5X$`,"=71,#P-U
M<`8#>@$*P0P!`$'#0<9!QT'%0PP$!$$+$````(@,``!ZHO__!`````````!(
M````G`P``'"B__]5`````$$."(4"00X,AP-!#A"&!$$.%(,%3@X@80XD00XH
M1`XL1`XP30X@1PX40<,.$$'&#@Q!QPX(0<4.!```$````.@,``"$HO__`0``
M```````H````_`P``("B__\K`````$$."(,"3@X01@X41`X81`X<1`X@2`X(
M0<,.!!@````H#0``A*+__Q0`````00X(@P).#A``````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````(`G```P)P```0````$````!````RP$`
M``$````:`@``#``````@```-````]&\``!D```#`W0``&P````0````:````
MQ-T``!P````$````]?[_;^P!```%````!`D```8```#$`@``"@```-D$```+
M````$````!4``````````P```-#>```"````X`$``!0````1````%P```-`/
M```1````2`\``!(```"(````$P````@````>````"````/O__V\!```(_O__
M;Z@.``#___]O`@```/#__V_>#0``^O__;P4`````````````````````````
M````````````````````````````````R-T`````````````-B```$8@``!6
M(```9B```'8@``"&(```EB```*8@``"V(```QB```-8@``#F(```]B````8A
M```6(0``)B$``#8A``!&(0``5B$``&8A``!V(0``AB$``)8A``"F(0``MB$`
M`,8A``#6(0``YB$``/8A```&(@``%B(``"8B```V(@``1B(``%8B``!F(@``
M=B(``(8B``"6(@``IB(``+8B``#&(@``UB(``.8B``#V(@``!B,``!8C```F
M(P``-B,``$8C``!6(P``9B,``'8C``"&(P``EB,``*8C``"V(P``QB,``-8C
M``#F(P``````````````````````````````````````````````````````
M`````````````"0````````$X```_____PB#``!'0T,Z("A58G5N='4@."XR
M+C`M.75B=6YT=3$I(#@N,BXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!
M0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE
M:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y
M`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````
M```````````````````````````````````+`````0````(```"4`0``E`$`
M`!,```````````````$`````````$P````<````"````J`$``*@!```@````
M```````````$`````````"$````'`````@```,@!``#(`0``)```````````
M````!``````````T````]O__;P(```#L`0``[`$``-@````%``````````0`
M```$````/@````L````"````Q`(``,0"``!`!@``!@````$````$````$```
M`$8````#`````@````0)```$"0``V00``````````````0````````!.````
M____;P(```#>#0``W@T``,@````%``````````(````"````6P```/[__V\"
M````J`X``*@.``"@````!@````(````$`````````&H````)`````@```$@/
M``!(#P``B`````4`````````!`````@```!S````"0```$(```#0#P``T`\`
M`.`!```%````%@````0````(````?`````$````&`````"`````@```@````
M```````````$`````````'<````!````!@```"`@```@(```T`,`````````
M````$`````0```""`````0````8```#P(P``\",```@```````````````@`
M```(````BP````$````&`````"0````D``#T2P`````````````0````````
M`)$````!````!@```/1O``#T;P``%```````````````!`````````"7````
M`0````(`````@````(```#P_``````````````0`````````GP````$````"
M````/+\``#R_``#T```````````````$`````````*T````!`````@```##`
M```PP```1`T`````````````!`````````"W````#@````,```#`W0``P,T`
M``0```````````````0````$````PP````\````#````Q-T``,3-```$````
M```````````$````!````,\````&`````P```,C=``#(S0``"`$```8`````
M````!`````@```"&`````0````,```#0W@``T,X``#`!``````````````0`
M```$````V`````$````#`````.````#0```0```````````````$````````
M`-X````(`````P```"#@```0T```-!``````````````(`````````#C````
M`0```#``````````$-```",```````````````$````!`````0````,`````
?`````````#/0``#L```````````````!````````````
